==> phpdox_0.8.0.orig.tar.gz: phpdox-0.8.0/src/docblock/elements/VarElement.php <==
<?php
/**
 * Copyright (c) 2010-2015 Arne Blankerts <arne@blankerts.de>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 *   * Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *
 *   * Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the documentation
 *     and/or other materials provided with the distribution.
 *
 *   * Neither the name of Arne Blankerts nor the names of contributors
 *     may be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT  * NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER ORCONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * @package    phpDox
 * @author     Arne Blankerts <arne@blankerts.de>
 * @copyright  Arne Blankerts <arne@blankerts.de>, All rights reserved.
 * @license    BSD License
 */

namespace TheSeer\phpDox\DocBlock {

    class VarElement extends GenericElement {

        const XMLNS = 'http://xml.phpdox.net/src';

        /**
         * @var string[]
         */
        private $types = array(
            '', 'mixed', '{unknown}', 'object', 'array', 'integer', 'int', 'float', 'string', 'boolean', 'resource'
        );

        public function asDom(\TheSeer\fDOM\fDOMDocument $ctx) {
            $node = parent::asDom($ctx);
            $type = $node->getAttribute('type');

            if (strpos($type, '[]')) {
                $type = mb_substr($type, 0, -2);
                $node->setAttribute('type', 'array');
                $node->setAttribute('of', $type);
            }

            if (!in_array($type, $this->types)) {
                if (!$node->hasAttribute('of')) {
                    $node->setAttribute('type', 'object');
                } else {
                    $node->setAttribute('of', 'object');
                }
                $parts = explode('\\', $type);
                $local = array_pop($parts);
                $namespace = join('\\', $parts);

                $class = $node->appendElementNS(self::XMLNS, 'type');
                $class->setAttribute('full', $type);
                $class->setAttribute('namespace', $namespace);
                $class->setAttribute('name', $local);

            }
            return $node;
        }
    }

}

==> phpdox_0.10.1.orig.tar.gz: phpdox-0.10.1/src/docblock/elements/VarElement.php <==
<?php
/**
 * Copyright (c) 2010-2017 Arne Blankerts <arne@blankerts.de>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 *   * Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *
 *   * Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the documentation
 *     and/or other materials provided with the distribution.
 *
 *   * Neither the name of Arne Blankerts nor the names of contributors
 *     may be used to endorse or promote products derived from this software
 *     without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT  * NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER ORCONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 * OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * @package    phpDox
 * @author     Arne Blankerts <arne@blankerts.de>
 * @copyright  Arne Blankerts <arne@blankerts.de>, All rights reserved.
 * @license    BSD License
 */

namespace TheSeer\phpDox\DocBlock {

    class VarElement extends GenericElement {

        const XMLNS = 'http://xml.phpdox.net/src';

        /**
         * @var string[]
         */
        private $types = array(
            '', 'null', 'mixed', '{unknown}', 'object', 'array', 'integer', 'int',
            'float', 'string', 'boolean', 'resource'
        );

        public function asDom(\TheSeer\fDOM\fDOMDocument $ctx) {
            $node = parent::asDom($ctx);
            $type = $node->getAttribute('type');

            if (strpos($type, '[]')) {
                $type = mb_substr($type, 0, -2);
                $node->setAttribute('type', 'array');
                $node->setAttribute('of', $type);
            }

            if (!in_array($type, $this->types)) {
                if (!$node->hasAttribute('of')) {
                    $node->setAttribute('type', 'object');
                } else {
                    $node->setAttribute('of', 'object');
                }
                $parts = explode('\\', $type);
                $local = array_pop($parts);
                $namespace = join('\\', $parts);

                $class = $node->appendElementNS(self::XMLNS, 'type');
                $class->setAttribute('full', $type);
                $class->setAttribute('namespace', $namespace);
                $class->setAttribute('name', $local);

            }
            return $node;
        }
    }

}
